runqueue

package
v0.8.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Dec 27, 2019 License: GPL-3.0 Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type RunQueue

type RunQueue struct {
	// contains filtered or unexported fields
}

func New

func New(name string) *RunQueue

func (*RunQueue) Run

func (m *RunQueue) Run(fn func())

func (*RunQueue) Stop

func (m *RunQueue) Stop(stopCb func())

Directories

Path Synopsis
Package mpsc provides an efficient implementation of a multi-producer, single-consumer lock-free queue.
Package mpsc provides an efficient implementation of a multi-producer, single-consumer lock-free queue.

Jump to