Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ChannelBindingMechanism ¶
type ChannelBindingMechanism int
ChannelBindingMechanism represents a scram channel binding mechanism.
const ( // TLSUnique represents 'tls-unique' channel binding mechanism. TLSUnique ChannelBindingMechanism = iota )
type Transport ¶
type Transport interface {
io.ReadWriteCloser
// Type returns transport type value.
Type() Type
// WriteString writes a raw string to the transport.
WriteString(s string) (n int, err error)
// Flush writes any buffered data to the underlying io.Writer.
Flush() error
// SetWriteDeadline sets the deadline for future write calls.
SetWriteDeadline(d time.Time) error
// SetReadRateLimiter sets transport read rate limiter.
SetReadRateLimiter(rLim *rate.Limiter) error
// StartTLS secures the transport using SSL/TLS
StartTLS(cfg *tls.Config, asClient bool)
// EnableCompression activates a compression mechanism on the transport.
EnableCompression(compress.Level)
// ChannelBindingBytes returns current transport channel binding bytes.
ChannelBindingBytes(ChannelBindingMechanism) []byte
// PeerCertificates returns the certificate chain presented by remote peer.
PeerCertificates() []*x509.Certificate
}
Transport represents a stream transport mechanism.
func NewSocketTransport ¶
NewSocketTransport creates a socket class stream transport.
Click to show internal directories.
Click to hide internal directories.